@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.007001'; # TRIAL VERSION
+our $VERSION = '0.007002'; # TRIAL VERSION
 
 use Moose;
 extends 'Business::CyberSource::Factory';
@@ -19,9 +19,17 @@ use Exception::Base (
 	},
 	'Business::CyberSource::Response::Exception' => {
 		isa => 'Business::CyberSource::Exception',
-		has => [
-			qw(decision reason_text reason_code request_id request_token trace)
-		],
+		has => [qw(
+			decision
+			reason_text
+			reason_code
+			request_id
+			request_token
+			trace
+			is_error
+			is_accept
+			is_reject
+		)],
 		string_attributes => [ qw( message decision reason_text ) ],
 	},
 	verbosity      => 4,
@@ -44,7 +52,7 @@ sub create {
 		}
 		catch {
 			my %exception = (
-				message       => 'CyberSource SOAP Response',
+				message       => 'BUG! please report: ' . $_,
 				reason_code   => $result->{reasonCode},
 				value         => $result->{reasonCode},
 				decision      => $result->{decision},
@@ -77,6 +85,9 @@ sub create {
 			decision      => $response->decision,
 			request_id    => $response->request_id,
 			request_token => $response->request_token,
+			is_error      => $response->is_error,
+			is_accept     => $response->is_accept,
+			is_reject     => $response->is_reject,
 		);
 		$exception{trace} = $response->trace if $response->has_trace;
 
@@ -108,7 +119,7 @@ Business::CyberSource::Factory::Response - A Response Factory
 
 =head1 VERSION
 
-version 0.007001
+version 0.007002
 
 =head1 METHODS
 
