@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.007001'; # TRIAL VERSION
+our $VERSION = '0.007002'; # TRIAL VERSION
 
 use Moose;
 extends 'Business::CyberSource::MessagePart';
@@ -12,9 +12,13 @@ with    'MooseX::RemoteHelper::CompositeSerialization';
 
 use MooseX::Aliases;
 
-use MooseX::Types::CyberSource qw( CvIndicator CardTypeCode ExpirationDate );
-use MooseX::Types::CreditCard 0.001001 qw( CreditCard CardSecurityCode     );
-use MooseX::Types::Common::String      qw( NonEmptySimpleStr               );
+use MooseX::Types::CyberSource      qw( CvIndicator CardTypeCode  );
+use MooseX::Types::Common::String   qw( NonEmptySimpleStr         );
+use MooseX::Types::CreditCard 0.002 qw(
+	CardNumber
+	CardSecurityCode
+	CardExpiration
+);
 
 use Exception::Base (
 	'Business::CyberSource::Card::Exception' => {
@@ -99,7 +103,7 @@ sub _build_card_type_code {
 }
 
 has account_number => (
-	isa         => CreditCard,
+	isa         => CardNumber,
 	remote_name => 'accountNumber',
 	alias       => [ qw( credit_card_number card_number ) ],
 	required    => 1,
@@ -116,7 +120,7 @@ has type => (
 );
 
 has expiration => (
-	isa      => ExpirationDate,
+	isa      => CardExpiration,
 	required => 1,
 	is       => 'ro',
 	coerce   => 1,
@@ -202,7 +206,11 @@ Business::CyberSource::RequestPart::Card - Credit Card Helper Class
 
 =head1 VERSION
 
-version 0.007001
+version 0.007002
+
+=head1 EXTENDS
+
+L<Business::CyberSource::MessagePart>
 
 =head1 ATTRIBUTES
 
@@ -310,10 +318,6 @@ cards, contact the CyberSource UK Support Group.
 
 =back
 
-=head1 EXTENDS
-
-L<Business::CyberSource::MessagePart>
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
