@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.007001'; # TRIAL VERSION
+our $VERSION = '0.007002'; # TRIAL VERSION
 
 use Moose;
 extends 'Business::CyberSource::MessagePart';
@@ -53,7 +53,33 @@ Business::CyberSource::ResponsePart::DCCReply - Reply section for DCC
 
 =head1 VERSION
 
-version 0.007001
+version 0.007002
+
+=head1 EXTENDS
+
+L<Business::CyberSource::MessagePart>
+
+=head2 WITH
+
+=over
+
+=item L<Business::CyberSource::Response::Role::ReasonCode>
+
+=back
+
+=head1 ATTRIBUTES
+
+=head2 dcc_supported
+
+B<Type:> C<Bool>
+
+=head2 margin_rate_percentage
+
+B<Type:> C<Num>
+
+=head2 valid_hours
+
+B<Type:> C<Int>
 
 =head1 BUGS
 
