@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.007001'; # TRIAL VERSION
+our $VERSION = '0.007002'; # TRIAL VERSION
 
 use Moose;
 extends 'Business::CyberSource::MessagePart';
@@ -26,7 +26,35 @@ Business::CyberSource::ResponsePart::PurchaseTotals - PurchaseTotals part of res
 
 =head1 VERSION
 
-version 0.007001
+version 0.007002
+
+=head1 EXTENDS
+
+L<Business::CyberSource::MessagePart>
+
+=head1 WITH
+
+=over
+
+=item L<Business::CyberSource::Role::Currency>
+
+=item L<Business::CyberSource::Role::ForeignCurrency>
+
+=back
+
+=head1 ATTRIBUTES
+
+=head2 currency
+
+=head2 foreign_currency
+
+Billing currency returned by the DCC service. For the possible values, see the ISO currency codes
+
+=head2 foreign_amount
+
+=head2 exchange_rate
+
+=head2 exchange_rate_timestamp
 
 =head1 BUGS
 
